@@ -12,9 +12,9 @@ var ANIMATED_ICON_UPDATE_TIMEOUT = 16;
 var Animation = new Lang.Class({
     Name: 'Animation',
 
-    _init: function(file, width, height, speed) {
+    _init(file, width, height, speed) {
         this.actor = new St.Bin();
-        this.actor.connect('destroy', Lang.bind(this, this._onDestroy));
+        this.actor.connect('destroy', this._onDestroy.bind(this));
         this._speed = speed;
 
         this._isLoaded = false;
@@ -24,23 +24,23 @@ var Animation = new Lang.Class({
 
         let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
         this._animations = St.TextureCache.get_default().load_sliced_image (file, width, height, scaleFactor,
-                                                                            Lang.bind(this, this._animationsLoaded));
+                                                                            this._animationsLoaded.bind(this));
         this.actor.set_child(this._animations);
     },
 
-    play: function() {
+    play() {
         if (this._isLoaded && this._timeoutId == 0) {
             if (this._frame == 0)
                 this._showFrame(0);
 
-            this._timeoutId = GLib.timeout_add(GLib.PRIORITY_LOW, this._speed, Lang.bind(this, this._update));
+            this._timeoutId = GLib.timeout_add(GLib.PRIORITY_LOW, this._speed, this._update.bind(this));
             GLib.Source.set_name_by_id(this._timeoutId, '[gnome-shell] this._update');
         }
 
         this._isPlaying = true;
     },
 
-    stop: function() {
+    stop() {
         if (this._timeoutId > 0) {
             Mainloop.source_remove(this._timeoutId);
             this._timeoutId = 0;
@@ -49,7 +49,7 @@ var Animation = new Lang.Class({
         this._isPlaying = false;
     },
 
-    _showFrame: function(frame) {
+    _showFrame(frame) {
         let oldFrameActor = this._animations.get_child_at_index(this._frame);
         if (oldFrameActor)
             oldFrameActor.hide();
@@ -61,19 +61,19 @@ var Animation = new Lang.Class({
             newFrameActor.show();
     },
 
-    _update: function() {
+    _update() {
         this._showFrame(this._frame + 1);
         return GLib.SOURCE_CONTINUE;
     },
 
-    _animationsLoaded: function() {
+    _animationsLoaded() {
         this._isLoaded = this._animations.get_n_children() > 0;
 
         if (this._isPlaying)
             this.play();
     },
 
-    _onDestroy: function() {
+    _onDestroy() {
         this.stop();
     }
 });
@@ -82,7 +82,7 @@ var AnimatedIcon = new Lang.Class({
     Name: 'AnimatedIcon',
     Extends: Animation,
 
-    _init: function(file, size) {
+    _init(file, size) {
         this.parent(file, size, size, ANIMATED_ICON_UPDATE_TIMEOUT);
     }
 });
