@@ -34,8 +34,8 @@ var extensionOrder = [];
 var _signals = {};
 Signals.addSignalMethods(_signals);
 
-var connect = Lang.bind(_signals, _signals.connect);
-var disconnect = Lang.bind(_signals, _signals.disconnect);
+var connect = _signals.connect.bind(_signals);
+var disconnect = _signals.disconnect.bind(_signals);
 
 const ENABLED_EXTENSIONS_KEY = 'enabled-extensions';
 const DISABLE_USER_EXTENSIONS_KEY = 'disable-user-extensions';
@@ -76,6 +76,7 @@ function disableExtension(uuid) {
     if (extension.stylesheet) {
         let theme = St.ThemeContext.get_for_stage(global.stage).get_theme();
         theme.unload_stylesheet(extension.stylesheet);
+        delete extension.stylesheet;
     }
 
     try {
@@ -115,13 +116,18 @@ function enableExtension(uuid) {
     extensionOrder.push(uuid);
 
     let stylesheetNames = [global.session_mode + '.css', 'stylesheet.css'];
+    let theme = St.ThemeContext.get_for_stage(global.stage).get_theme();
     for (let i = 0; i < stylesheetNames.length; i++) {
-        let stylesheetFile = extension.dir.get_child(stylesheetNames[i]);
-        if (stylesheetFile.query_exists(null)) {
-            let theme = St.ThemeContext.get_for_stage(global.stage).get_theme();
+        try {
+            let stylesheetFile = extension.dir.get_child(stylesheetNames[i]);
             theme.load_stylesheet(stylesheetFile);
             extension.stylesheet = stylesheetFile;
             break;
+        } catch (e) {
+            if (e.matches(Gio.IOErrorEnum, Gio.IOErrorEnum.NOT_FOUND))
+                continue; // not an error
+            log(`Failed to load stylesheet for extension ${uuid}: ${e.message}`);
+            return;
         }
     }
 
@@ -131,6 +137,10 @@ function enableExtension(uuid) {
         _signals.emit('extension-state-changed', extension);
         return;
     } catch(e) {
+        if (extension.stylesheet) {
+            theme.unload_stylesheet(extension.stylesheet);
+            delete extension.stylesheet;
+        }
         logExtensionError(uuid, e);
         return;
     }
@@ -273,17 +283,17 @@ function onEnabledExtensionsChanged() {
 
     // Find and enable all the newly enabled extensions: UUIDs found in the
     // new setting, but not in the old one.
-    newEnabledExtensions.filter(function(uuid) {
-        return enabledExtensions.indexOf(uuid) == -1;
-    }).forEach(function(uuid) {
+    newEnabledExtensions.filter(
+        uuid => !enabledExtensions.includes(uuid)
+    ).forEach(uuid => {
         enableExtension(uuid);
     });
 
     // Find and disable all the newly disabled extensions: UUIDs found in the
     // old setting, but not in the new one.
-    enabledExtensions.filter(function(item) {
-        return newEnabledExtensions.indexOf(item) == -1;
-    }).forEach(function(uuid) {
+    enabledExtensions.filter(
+        item => !newEnabledExtensions.includes(item)
+    ).forEach(uuid => {
         disableExtension(uuid);
     });
 
@@ -300,7 +310,7 @@ function _onVersionValidationChanged() {
     enabledExtensions = getEnabledExtensions();
 
     if (Main.sessionMode.allowExtensions) {
-        enabledExtensions.forEach(function(uuid) {
+        enabledExtensions.forEach(uuid => {
             enableExtension(uuid);
         });
     }
@@ -314,7 +324,7 @@ function _loadExtensions() {
     enabledExtensions = getEnabledExtensions();
 
     let finder = new ExtensionUtils.ExtensionFinder();
-    finder.connect('extension-found', function(finder, extension) {
+    finder.connect('extension-found', (finder, extension) => {
         loadExtension(extension);
     });
     finder.scanExtensions();
@@ -328,7 +338,7 @@ function enableAllExtensions() {
         _loadExtensions();
         initted = true;
     } else {
-        enabledExtensions.forEach(function(uuid) {
+        enabledExtensions.forEach(uuid => {
             enableExtension(uuid);
         });
     }
@@ -340,7 +350,7 @@ function disableAllExtensions() {
         return;
 
     if (initted) {
-        extensionOrder.slice().reverse().forEach(function(uuid) {
+        extensionOrder.slice().reverse().forEach(uuid => {
             disableExtension(uuid);
         });
     }
