@@ -61,7 +61,7 @@ const ScreenshotIface = '<node> \
 var ScreenshotService = new Lang.Class({
     Name: 'ScreenshotService',
 
-    _init: function() {
+    _init() {
         this._dbusImpl = Gio.DBusExportedObject.wrapJSObject(ScreenshotIface, this);
         this._dbusImpl.export(Gio.DBus.session, '/org/gnome/Shell/Screenshot');
 
@@ -72,7 +72,7 @@ var ScreenshotService = new Lang.Class({
         Gio.DBus.session.own_name('org.gnome.Shell.Screenshot', Gio.BusNameOwnerFlags.REPLACE, null, null);
     },
 
-    _createScreenshot: function(invocation) {
+    _createScreenshot(invocation) {
         let sender = invocation.get_sender();
         if (this._screenShooter.has(sender) ||
             this._lockdownSettings.get_boolean('disable-save-to-disk')) {
@@ -83,18 +83,18 @@ var ScreenshotService = new Lang.Class({
         let shooter = new Shell.Screenshot();
         shooter._watchNameId =
                         Gio.bus_watch_name(Gio.BusType.SESSION, sender, 0, null,
-                                           Lang.bind(this, this._onNameVanished));
+                                           this._onNameVanished.bind(this));
 
         this._screenShooter.set(sender, shooter);
 
         return shooter;
     },
 
-    _onNameVanished: function(connection, name) {
+    _onNameVanished(connection, name) {
         this._removeShooterForSender(name);
     },
 
-    _removeShooterForSender: function(sender) {
+    _removeShooterForSender(sender) {
         let shooter = this._screenShooter.get(sender);
         if (!shooter)
             return;
@@ -103,20 +103,20 @@ var ScreenshotService = new Lang.Class({
         this._screenShooter.delete(sender);
     },
 
-    _checkArea: function(x, y, width, height) {
+    _checkArea(x, y, width, height) {
         return x >= 0 && y >= 0 &&
                width > 0 && height > 0 &&
                x + width <= global.screen_width &&
                y + height <= global.screen_height;
     },
 
-    _onScreenshotComplete: function(obj, result, area, filenameUsed, flash, invocation) {
+    _onScreenshotComplete(obj, result, area, filenameUsed, flash, invocation) {
         if (result) {
             if (flash) {
                 let flashspot = new Flashspot(area);
-                flashspot.fire(Lang.bind(this, function() {
+                flashspot.fire(() => {
                     this._removeShooterForSender(invocation.get_sender());
-                }));
+                });
             }
             else
                 this._removeShooterForSender(invocation.get_sender());
@@ -126,7 +126,7 @@ var ScreenshotService = new Lang.Class({
         invocation.return_value(retval);
     },
 
-    _scaleArea: function(x, y, width, height) {
+    _scaleArea(x, y, width, height) {
         let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
         x *= scaleFactor;
         y *= scaleFactor;
@@ -135,7 +135,7 @@ var ScreenshotService = new Lang.Class({
         return [x, y, width, height];
     },
 
-    _unscaleArea: function(x, y, width, height) {
+    _unscaleArea(x, y, width, height) {
         let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
         x /= scaleFactor;
         y /= scaleFactor;
@@ -144,7 +144,7 @@ var ScreenshotService = new Lang.Class({
         return [x, y, width, height];
     },
 
-    ScreenshotAreaAsync : function (params, invocation) {
+    ScreenshotAreaAsync(params, invocation) {
         let [x, y, width, height, flash, filename, callback] = params;
         [x, y, width, height] = this._scaleArea(x, y, width, height);
         if (!this._checkArea(x, y, width, height)) {
@@ -157,48 +157,53 @@ var ScreenshotService = new Lang.Class({
         if (!screenshot)
             return;
         screenshot.screenshot_area (x, y, width, height, filename,
-                                Lang.bind(this, this._onScreenshotComplete,
-                                          flash, invocation));
+            (obj, result, area, filenameUsed) => {
+                this._onScreenshotComplete(obj, result, area, filenameUsed,
+                                           flash, invocation);
+            });
     },
 
-    ScreenshotWindowAsync : function (params, invocation) {
+    ScreenshotWindowAsync(params, invocation) {
         let [include_frame, include_cursor, flash, filename] = params;
         let screenshot = this._createScreenshot(invocation);
         if (!screenshot)
             return;
         screenshot.screenshot_window (include_frame, include_cursor, filename,
-                                  Lang.bind(this, this._onScreenshotComplete,
-                                            flash, invocation));
+            (obj, result, area, filenameUsed) => {
+                this._onScreenshotComplete(obj, result, area, filenameUsed,
+                                           flash, invocation);
+            });
     },
 
-    ScreenshotAsync : function (params, invocation) {
+    ScreenshotAsync(params, invocation) {
         let [include_cursor, flash, filename] = params;
         let screenshot = this._createScreenshot(invocation);
         if (!screenshot)
             return;
         screenshot.screenshot(include_cursor, filename,
-                          Lang.bind(this, this._onScreenshotComplete,
-                                    flash, invocation));
+            (obj, result, area, filenameUsed) => {
+                this._onScreenshotComplete(obj, result, area, filenameUsed,
+                                           flash, invocation);
+            });
     },
 
-    SelectAreaAsync: function (params, invocation) {
+    SelectAreaAsync(params, invocation) {
         let selectArea = new SelectArea();
         selectArea.show();
-        selectArea.connect('finished', Lang.bind(this,
-            function(selectArea, areaRectangle) {
-                if (areaRectangle) {
-                    let retRectangle = this._unscaleArea(areaRectangle.x, areaRectangle.y,
-                        areaRectangle.width, areaRectangle.height);
-                    let retval = GLib.Variant.new('(iiii)', retRectangle);
-                    invocation.return_value(retval);
-                } else {
-                    invocation.return_error_literal(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED,
-                        "Operation was cancelled");
-                }
-            }));
+        selectArea.connect('finished', (selectArea, areaRectangle) => {
+            if (areaRectangle) {
+                let retRectangle = this._unscaleArea(areaRectangle.x, areaRectangle.y,
+                    areaRectangle.width, areaRectangle.height);
+                let retval = GLib.Variant.new('(iiii)', retRectangle);
+                invocation.return_value(retval);
+            } else {
+                invocation.return_error_literal(Gio.IOErrorEnum, Gio.IOErrorEnum.CANCELLED,
+                    "Operation was cancelled");
+            }
+        });
     },
 
-    FlashAreaAsync: function(params, invocation) {
+    FlashAreaAsync(params, invocation) {
         let [x, y, width, height] = params;
         [x, y, width, height] = this._scaleArea(x, y, width, height);
         if (!this._checkArea(x, y, width, height)) {
@@ -216,7 +221,7 @@ var ScreenshotService = new Lang.Class({
 var SelectArea = new Lang.Class({
     Name: 'SelectArea',
 
-    _init: function() {
+    _init() {
         this._startX = -1;
         this._startY = -1;
         this._lastX = 0;
@@ -234,11 +239,11 @@ var SelectArea = new Lang.Class({
         this._grabHelper = new GrabHelper.GrabHelper(this._group);
 
         this._group.connect('button-press-event',
-                            Lang.bind(this, this._onButtonPress));
+                            this._onButtonPress.bind(this));
         this._group.connect('button-release-event',
-                            Lang.bind(this, this._onButtonRelease));
+                            this._onButtonRelease.bind(this));
         this._group.connect('motion-event',
-                            Lang.bind(this, this._onMotionEvent));
+                            this._onMotionEvent.bind(this));
 
         let constraint = new Clutter.BindConstraint({ source: global.stage,
                                                       coordinate: Clutter.BindCoordinate.ALL });
@@ -251,9 +256,9 @@ var SelectArea = new Lang.Class({
         this._group.add_actor(this._rubberband);
     },
 
-    show: function() {
+    show() {
         if (!this._grabHelper.grab({ actor: this._group,
-                                     onUngrab: Lang.bind(this, this._onUngrab) }))
+                                     onUngrab: this._onUngrab.bind(this) }))
             return;
 
         global.screen.set_cursor(Meta.Cursor.CROSSHAIR);
@@ -261,7 +266,7 @@ var SelectArea = new Lang.Class({
         this._group.visible = true;
     },
 
-    _initRubberbandColors: function() {
+    _initRubberbandColors() {
         function colorFromRGBA(rgba) {
             return new Clutter.Color({ red: rgba.red * 255,
                                        green: rgba.green * 255,
@@ -280,14 +285,14 @@ var SelectArea = new Lang.Class({
         this._border = colorFromRGBA(context.get_border_color(Gtk.StateFlags.NORMAL));
     },
 
-    _getGeometry: function() {
+    _getGeometry() {
         return { x: Math.min(this._startX, this._lastX),
                  y: Math.min(this._startY, this._lastY),
                  width: Math.abs(this._startX - this._lastX) + 1,
                  height: Math.abs(this._startY - this._lastY) + 1 };
     },
 
-    _onMotionEvent: function(actor, event) {
+    _onMotionEvent(actor, event) {
         if (this._startX == -1 || this._startY == -1)
             return Clutter.EVENT_PROPAGATE;
 
@@ -302,7 +307,7 @@ var SelectArea = new Lang.Class({
         return Clutter.EVENT_PROPAGATE;
     },
 
-    _onButtonPress: function(actor, event) {
+    _onButtonPress(actor, event) {
         [this._startX, this._startY] = event.get_coords();
         this._startX = Math.floor(this._startX);
         this._startY = Math.floor(this._startY);
@@ -311,29 +316,27 @@ var SelectArea = new Lang.Class({
         return Clutter.EVENT_PROPAGATE;
     },
 
-    _onButtonRelease: function(actor, event) {
+    _onButtonRelease(actor, event) {
         this._result = this._getGeometry();
         Tweener.addTween(this._group,
                          { opacity: 0,
                            time: 0.2,
                            transition: 'easeOutQuad',
-                           onComplete: Lang.bind(this,
-                               function() {
-                                   this._grabHelper.ungrab();
-                               })
+                           onComplete: () => {
+                               this._grabHelper.ungrab();
+                           }
                          });
         return Clutter.EVENT_PROPAGATE;
     },
 
-    _onUngrab: function() {
+    _onUngrab() {
         global.screen.set_cursor(Meta.Cursor.DEFAULT);
         this.emit('finished', this._result);
 
-        GLib.idle_add(GLib.PRIORITY_DEFAULT, Lang.bind(this,
-            function() {
-                this._group.destroy();
-                return GLib.SOURCE_REMOVE;
-            }));
+        GLib.idle_add(GLib.PRIORITY_DEFAULT, () => {
+            this._group.destroy();
+            return GLib.SOURCE_REMOVE;
+        });
     }
 });
 Signals.addSignalMethods(SelectArea.prototype);
@@ -344,7 +347,7 @@ var Flashspot = new Lang.Class({
     Name: 'Flashspot',
     Extends: Lightbox.Lightbox,
 
-    _init: function(area) {
+    _init(area) {
         this.parent(Main.uiGroup, { inhibitEvents: true,
                                     width: area.width,
                                     height: area.height });
@@ -353,18 +356,18 @@ var Flashspot = new Lang.Class({
         this.actor.set_position(area.x, area.y);
     },
 
-    fire: function(doneCallback) {
+    fire(doneCallback) {
         this.actor.show();
         this.actor.opacity = 255;
         Tweener.addTween(this.actor,
                          { opacity: 0,
                            time: FLASHSPOT_ANIMATION_OUT_TIME,
                            transition: 'easeOutQuad',
-                           onComplete: Lang.bind(this, function() {
+                           onComplete: () => {
                                if (doneCallback)
                                    doneCallback();
                                this.destroy();
-                           })
+                           }
                          });
     }
 });
