@@ -9,7 +9,7 @@ var Indicator = new Lang.Class({
     Name: 'ScreencastIndicator',
     Extends: PanelMenu.SystemIndicator,
 
-    _init: function() {
+    _init() {
         this.parent();
 
         this._indicator = this._addIndicator();
@@ -17,10 +17,10 @@ var Indicator = new Lang.Class({
         this._indicator.add_style_class_name('screencast-indicator');
         this._sync();
 
-        Main.screencastService.connect('updated', Lang.bind(this, this._sync));
+        Main.screencastService.connect('updated', this._sync.bind(this));
     },
 
-    _sync: function() {
+    _sync() {
         this._indicator.visible = Main.screencastService.isRecording;
     },
 });
